#!/bin/sh

PATH=/sbin:/bin:/usr/bin:/usr/sbin
TMPDIR=/mnt/ramdisk
BACKUPFILE=${TMPDIR}/backuptrackerconfig
VERSIONFILE=../pkgVersion.xml
VERSION=`/usr/bin/tinyxmlparser -x /tracker/conf.d -f ${VERSIONFILE}`
MODEL=`confclient -g system_info_extendedmodelname -p 9 -t Value`
OPENSSLKEY="${MODEL}-${VERSION}"

CONFCLIENT=/usr/sbin/confclient
CDF_BACKUP_OPTION="system_mvaas&system_location&reportpush&server&media&vadp_event_triggerlist&event&di&do&tracker"
IBIS_SC813X_OPTION="&camctrl_c0_cameraid&uart_i0_baudrate&uart_i1_baudrate"
IBIS_SC9133_OPTION="&ibis_cameraid&uart_i0_baudrate&uart_i1_baudrate"
CDF_BACKUP_OPTION_FILE=${TMPDIR}/backupCDFlist.xml

Create_Backup_File()
{
	cd ../
	local userConfDir=conf.d/usrdef
	local jsonConfDir=conf.d/vca
	local imageConfDir=/etc/conf.d/image_cfgs/c0/etc
	local trackerVersion=pkgVersion.xml
	local trackerConfig=tracker_config.xml
	local intrinsics=/mnt/flash2/intrinsics.yml
	local intrinsics_ldc="${imageConfDir}"/intrinsics_ldc.yml
	local extrinsics=/mnt/flash2/extrinsics.yml
	local cylindCalibration="${imageConfDir}"/cylind_calibration.yml
	local sensorCalibration=/etc/conf.d/sensorcalibration_c0_coef.xml
	local sensorCalibrationDefault=/etc/conf.d/sensorcalibration_c0_coef_default.xml
	local hardwareDefine=/etc/conf.d/hardware_define.xml
	local imageFeature=/etc/conf.d/config_imagefeature_c0.xml
	local configSystemInfo=/etc/conf.d/config_systeminfo.xml
	local configVideoMode=/etc/conf.d/config_videomode_c0.xml
	if [ ${MODEL} = "SC8132" ] || [ ${MODEL} = "SC8133" ]; then
		${CONFCLIENT} -g "${CDF_BACKUP_OPTION}${IBIS_SC813X_OPTION}" -t XML -p 7 > ${CDF_BACKUP_OPTION_FILE}
	elif [ ${MODEL} = "SC9133" ]; then
		${CONFCLIENT} -g "${CDF_BACKUP_OPTION}${IBIS_SC9133_OPTION}" -t XML -p 7 > ${CDF_BACKUP_OPTION_FILE}
	else
		${CONFCLIENT} -g "${CDF_BACKUP_OPTION}" -t XML -p 7 > ${CDF_BACKUP_OPTION_FILE}
	fi
	
	mkdir -p ${TMPDIR}/vcatool/conf.d
	local vcaToolDir=${TMPDIR}/vcatool/conf.d
	
	[ ! -d "${userConfDir}" ] || [ ! -d "${jsonConfDir}" ] || ] [ ! -e "${trackerVersion}" ] || [ ! -e "${CDF_BACKUP_OPTION_FILE}" ] || [ ! -e "${trackerConfig}" ] && return 1
	
	local allFilePath="${userConfDir} ${jsonConfDir} ${trackerVersion} ${CDF_BACKUP_OPTION_FILE} ${trackerConfig}"
	
	if [ -d "${imageConfDir}" ]
	then
		allFilePath="${allFilePath} ${imageConfDir}"
	fi
	
	if [ ! -f "${intrinsics}" ]
	then
		local intrinsics="${imageConfDir}"/intrinsics.yml
		if [ ! -f "${intrinsics}" ]
		then
			local intrinsics=intrinsic/"${MODEL}"/intrinsics.yml
		fi
	fi
	if [ -f "${intrinsics}" ]
	then
		allFilePath="${allFilePath} ${intrinsics}"
		cp ${intrinsics} ${vcaToolDir}
	fi
	
	if [ ! -f "${intrinsics_ldc}" ]
	then
		local intrinsics_ldc=intrinsic/"${MODEL}"/intrinsics_ldc.yml
	fi
	if [ -f "${intrinsics_ldc}" ]
	then
		allFilePath="${allFilePath} ${intrinsics_ldc}"
		cp ${intrinsics_ldc} ${vcaToolDir}
	fi
	
	if [ -f "${extrinsics}" ]
	then
		allFilePath="${allFilePath} ${extrinsics}"
		cp ${extrinsics} ${vcaToolDir}
	fi
	
	if [ ! -f "${cylindCalibration}" ]
	then
		local cylindCalibration="${jsonConfDir}"/cylind_calibration.yml
	fi
	if [ -f "${cylindCalibration}" ]
	then
		allFilePath="${allFilePath} ${cylindCalibration}"
		cp ${cylindCalibration} ${vcaToolDir}
	fi
	
	if [ -f "${sensorCalibration}" ]
	then
		allFilePath="${allFilePath} ${sensorCalibration}"
		cp ${sensorCalibration} ${vcaToolDir}
	fi

	if [ -f "${sensorCalibrationDefault}" ]
	then
		allFilePath="${allFilePath} ${sensorCalibrationDefault}"
		cp ${sensorCalibrationDefault} ${vcaToolDir}
	fi

	if [ -f "${hardwareDefine}" ]
	then
		allFilePath="${allFilePath} ${hardwareDefine}"
		cp ${hardwareDefine} ${vcaToolDir}
	fi

	if [ -f "${imageFeature}" ]
	then
		allFilePath="${allFilePath} ${imageFeature}"
		cp ${imageFeature} ${vcaToolDir}
	fi

	if [ -f "${configVideoMode}" ]
	then
		allFilePath="${allFilePath} ${configVideoMode}"
		cp ${configVideoMode} ${vcaToolDir}
	fi

	if [ -f "${configSystemInfo}" ]
	then
		allFilePath="${allFilePath} ${configSystemInfo}"
	fi
	
	allFilePath="${allFilePath} ${vcaToolDir}"
	
	tar jcf - ${allFilePath} | openssl enc -aes-256-cbc -out ${BACKUPFILE} -e -salt -k ${OPENSSLKEY}
	strlog=`ls -l ${BACKUPFILE} | awk -F' ' '{print $5}'`
	rm -rf ${TMPDIR}/vcatool
	return 0   
}

Create_Backup_File
[ $? -eq 0 ] && {
	echo -ne "Content-type: text/plain\r\n"
	echo -ne "Content-Disposition: attachment; filename=VCA-Configurations-v${VERSION}-$(date +%Y%m%d)\r\n"
	echo -ne "Content-length:${strlog}\r\n\r\n"
	cat $BACKUPFILE>&1
	rm -rf $BACKUPFILE
	rm -rf $CDF_BACKUP_OPTION_FILE
}
